Installation
============

bookstore may be installed using Python 3.6 and above.

After installation, bookstore can process Python 2 or Python 3 notebooks.

Install from PyPI (recommended)
-------------------------------

.. code-block:: bash

    python3 -m pip install bookstore

Install from Source
-------------------

1. Clone this repo:

    .. code-block:: bash

        git clone https://github.com/nteract/bookstore.git

2. Change directory to repo root:

    .. code-block:: bash

        cd bookstore

3. Install dependencies:

    .. code-block:: bash

        python3 -m pip install -r requirements.txt
        python3 -m pip install -r requirements-dev.txt

4. Install package from source:

    .. code-block:: bash

        python3 -m pip install .

    .. tip:: Don't forget the dot at the end of the command